#define PROOFtestSelector_cxx
// The class definition in PROOFtestSelector.h has been generated automatically
// by the ROOT utility TTree::MakeSelector(). This class is derived
// from the ROOT class TSelector. For more information on the TSelector
// framework see $ROOTSYS/README/README.SELECTOR or the ROOT User Manual.

// The following methods are defined in this file:
//    Begin():        called everytime a loop on the tree starts,
//                    a convenient place to create your histograms.
//    SlaveBegin():   called after Begin(), when on PROOF called only on the
//                    slave servers.
//    Process():      called for each event, in this function you decide what
//                    to read and fill your histograms.
//    SlaveTerminate: called at the end of the loop on the tree, when on PROOF
//                    called only on the slave servers.
//    Terminate():    called at the end of the loop on the tree,
//                    a convenient place to draw/fit your histograms.
//
// To use this file, try the following session on your Tree T:
//
// Root > T->Process("PROOFtestSelector.C")
// Root > T->Process("PROOFtestSelector.C","some options")
// Root > T->Process("PROOFtestSelector.C+")
//

#include "PROOFtestSelector.h"
#include <TH2.h>
#include <TStyle.h>


void PROOFtestSelector::Begin(TTree * /*tree*/)
{
   // The Begin() function is called at the start of the query.
   // When running with PROOF Begin() is only called on the client.
   // The tree argument is deprecated (on PROOF 0 is passed).

  TString option = GetOption();
  timer = new TStopwatch;
}

void PROOFtestSelector::SlaveBegin(TTree * /*tree*/)
{
   // The SlaveBegin() function is called after the Begin() function.
   // When running with PROOF SlaveBegin() is called on each slave server.
   // The tree argument is deprecated (on PROOF 0 is passed).

   TString option = GetOption();
   gROOT->cd();
   energy = new TH1F("energy","energy",256,0,10);
   pxpy = new TH2F("pxpy","pxpy",256,-5,5,256,-5,5);
   treetest = new TTree("treetest","treetest");
   treetest->Branch("CalE",&CalE,"CalE/D");
   fOutput->Add(treetest);
   fOutput->Add(energy);
   fOutput->Add(pxpy);
}

Bool_t PROOFtestSelector::Process(Long64_t entry)
{
   // The Process() function is called for each entry in the tree (or possibly
   // keyed object in the case of PROOF) to be processed. The entry argument
   // specifies which entry in the currently loaded tree is to be processed.
   // It can be passed to either PROOFtestSelector::GetEntry() or 
   // TBranch::GetEntry()
   // to read either all or the required parts of the data. When processing
   // keyed objects with PROOF, the object is already loaded and is available
   // via the fObject pointer.
   //
   // This function should contain the "body" of the analysis. It can contain
   // simple or elaborate selection criteria, run algorithms on the data
   // of the event and typically fill histograms.
   //
   // The processing can be stopped by calling Abort().
   //
   // Use fStatus to set the return value of TTree::Process().
   //
   // The return value is currently not used.
  fChain->GetEntry(entry);
  CalE = sqrt(px*px+py*py+pz*pz);
  energy->Fill(CalE);
  pxpy->Fill(px,py);
  treetest->Fill();
  if ((entry+1)%100000==0){
    cout << 100*(entry+1)/(1.*fChain->GetEntries()) << "\r";
    cout.flush();
  }
   return kTRUE;
}

void PROOFtestSelector::SlaveTerminate()
{
   // The SlaveTerminate() function is called after all entries or objects
   // have been processed. When running with PROOF SlaveTerminate() is called
   // on each slave server.
  std::cout << "This slave filled with " << energy->GetEntries() << std::endl;
}

void PROOFtestSelector::Terminate()
{
   // The Terminate() function is the last function to be called during
   // a query. It always runs on the client, it can be used to present
   // the results graphically or save the results to file.
  std::cout << "Time processing: " << timer->RealTime() << std::endl;
  timer->Start();
  utfil = new TFile("PROOFtestOUTPUT.root","RECREATE");
  fOutput->Write();
  utfil->Close();
  std::cout << "Time writing result to disk: " << timer->RealTime() << std::endl;
}
